==> xsns_1.0.2.zip: xsns_1.0.2/xoops_trust_path/modules/xsns/act/mypage/config_edit_execAction.php <==
<?php

class config_edit_execAction extends mypageAction
{

function dispatch(&$context)
{
	global $xoopsUser;
	
	if($this->isGuest() || !$this->validateToken('CONFIG_EDIT')){
		redirect_header(APP_BASE_URL, 2, _NOPERM);
	}
	
	$own_uid = $xoopsUser->getVar('uid');
	
	$config_arr = $this->getConfigArray();
	if(is_null($config_arr)){
		redirect_header(_CM_URL_MYPAGE, 2, _CM_CONFIG_CHANGE_NG);
	}
	
	$module_config_handler =& CM_ModuleConfigHandler::getInstance();
	$module_config =& $module_config_handler->get($own_uid);
	if(!is_object($module_config)){
		$module_config =& $module_config_handler->create();
		$module_config->setVar('uid', $own_uid);
	}
	$module_config->setVar('config', $config_arr);
	
	if($module_config_handler->insert($module_config)){
		redirect_header(_CM_URL_MYPAGE_NEWS.'&uid='.$own_uid, 2, _CM_CONFIG_CHANGE_OK);
	}
	redirect_header(_CM_URL_MYPAGE, 2, _CM_CONFIG_CHANGE_NG);
}
//------------------------------------------------------------------------------

function getConfigArray()
{
	$mid = isset($_POST['mid'])? $_POST['mid'] : NULL;
	$oid = isset($_POST['order'])? $_POST['order'] : NULL;
	$view = isset($_POST['view'])? $_POST['view'] : NULL;
	
	if(!is_array($mid) || !is_array($oid) || !is_array($view)){
		return NULL;
	}
	
	$m_count = count($mid);
	$o_count = count($oid);
	$v_count = count($view);
	
	if($m_count!=$o_count || $m_count!=$v_count){
		return NULL;
	}
	
	$temp_array = array();
	$config_array = array();
	
	for($i=0; $i<$m_count; $i++){
		$mid[$i] = intval($mid[$i]);
		$oid[$i] = intval($oid[$i]);
		$view[$i] = intval($view[$i]);
		
		if($oid[$i]<0 || $oid[$i]>100){
			$oid[$i] = 0;
		}
		if($view[$i]<0 || $view[$i]>100){
			$view[$i] = 0;
		}
		
		$order_value[$mid[$i]] = $oid[$i];
		
		$temp_array[$mid[$i]] = array(
			'order' => $oid[$i], 'view' => $view[$i],
		);
	}
	asort($order_value);
	
	foreach($order_value as $key => $value){
		$config_array[$key] = $temp_array[$key];
	}
	return $config_array;
}

}

?>

==> xsns_1.0.4.zip: xsns_1.0.4/xoops_trust_path/modules/xsns/act/mypage/config_edit_execAction.php <==
<?php

class config_edit_execAction extends mypageAction
{

function dispatch(&$context)
{
	global $xoopsUser;
	
	if($this->isGuest() || !$this->validateToken('CONFIG_EDIT')){
		redirect_header(APP_BASE_URL, 2, _NOPERM);
	}
	
	$own_uid = $xoopsUser->getVar('uid');
	
	$config_arr = $this->getConfigArray();
	if(is_null($config_arr)){
		redirect_header(_CM_URL_MYPAGE, 2, _CM_CONFIG_CHANGE_NG);
	}
	
	$module_config_handler =& CM_ModuleConfigHandler::getInstance();
	$module_config =& $module_config_handler->get($own_uid);
	if(!is_object($module_config)){
		$module_config =& $module_config_handler->create();
		$module_config->setVar('uid', $own_uid);
	}
	$module_config->setVar('config', $config_arr);
	
	if($module_config_handler->insert($module_config, false, true)){
		redirect_header(_CM_URL_MYPAGE_NEWS.'&uid='.$own_uid, 2, _CM_CONFIG_CHANGE_OK);
	}
	redirect_header(_CM_URL_MYPAGE, 2, _CM_CONFIG_CHANGE_NG);
}
//------------------------------------------------------------------------------

function getConfigArray()
{
	$mid = isset($_POST['mid'])? $_POST['mid'] : NULL;
	$oid = isset($_POST['order'])? $_POST['order'] : NULL;
	$view = isset($_POST['view'])? $_POST['view'] : NULL;
	
	if(!is_array($mid) || !is_array($oid) || !is_array($view)){
		return NULL;
	}
	
	$m_count = count($mid);
	$o_count = count($oid);
	$v_count = count($view);
	
	if($m_count!=$o_count || $m_count!=$v_count){
		return NULL;
	}
	
	$temp_array = array();
	$config_array = array();
	
	for($i=0; $i<$m_count; $i++){
		$mid[$i] = intval($mid[$i]);
		$oid[$i] = intval($oid[$i]);
		$view[$i] = intval($view[$i]);
		
		if($oid[$i]<0 || $oid[$i]>100){
			$oid[$i] = 0;
		}
		if($view[$i]<0 || $view[$i]>100){
			$view[$i] = 0;
		}
		
		$order_value[$mid[$i]] = $oid[$i];
		
		$temp_array[$mid[$i]] = array(
			'order' => $oid[$i], 'view' => $view[$i],
		);
	}
	asort($order_value);
	
	foreach($order_value as $key => $value){
		$config_array[$key] = $temp_array[$key];
	}
	return $config_array;
}

}

?>
